==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/invocation/impl/BridgeInvocationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.invocation.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.BridgeSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeSetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.BridgeInvocation;
import io.ciera.tool.sql.ooaofooa.invocation.BridgeInvocationSet;
import io.ciera.tool.sql.ooaofooa.value.V_PARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_PARSetImpl;

import java.util.Arrays;
import java.util.List;


public class BridgeInvocationSetImpl extends InstanceSet<BridgeInvocationSet,BridgeInvocation> implements BridgeInvocationSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( BridgeInvocation bridgeinvocation : this ) bridgeinvocation.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setExternalEntityKeyLettersLineNumber( int m_externalEntityKeyLettersLineNumber ) throws XtumlException {
        for ( BridgeInvocation bridgeinvocation : this ) bridgeinvocation.setExternalEntityKeyLettersLineNumber( m_externalEntityKeyLettersLineNumber );
    }
    @Override
    public void setExternalEntityKeyLettersColumn( int m_externalEntityKeyLettersColumn ) throws XtumlException {
        for ( BridgeInvocation bridgeinvocation : this ) bridgeinvocation.setExternalEntityKeyLettersColumn( m_externalEntityKeyLettersColumn );
    }
    @Override
    public void setBridgeNameLineNumber( int m_bridgeNameLineNumber ) throws XtumlException {
        for ( BridgeInvocation bridgeinvocation : this ) bridgeinvocation.setBridgeNameLineNumber( m_bridgeNameLineNumber );
    }
    @Override
    public void setBrg_ID( UniqueId ref_Brg_ID ) throws XtumlException {
        for ( BridgeInvocation bridgeinvocation : this ) bridgeinvocation.setBrg_ID( ref_Brg_ID );
    }
    @Override
    public void setBridgeNameColumn( int m_bridgeNameColumn ) throws XtumlException {
        for ( BridgeInvocation bridgeinvocation : this ) bridgeinvocation.setBridgeNameColumn( m_bridgeNameColumn );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( BridgeInvocation bridgeinvocation : this ) act_smtset.add( bridgeinvocation.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public V_PARSet R628_takes_V_PAR() throws XtumlException {
        V_PARSet v_parset = new V_PARSetImpl();
        for ( BridgeInvocation bridgeinvocation : this ) v_parset.addAll( bridgeinvocation.R628_takes_V_PAR() );
        return v_parset;
    }
    @Override
    public BridgeSet R674_is_an_invocation_of_Bridge() throws XtumlException {
        BridgeSet bridgeset = new BridgeSetImpl();
        for ( BridgeInvocation bridgeinvocation : this ) bridgeset.add( bridgeinvocation.R674_is_an_invocation_of_Bridge() );
        return bridgeset;
    }


    @Override
    public BridgeInvocation nullElement() {
        return BridgeInvocationImpl.EMPTY_BRIDGEINVOCATION;
    }

    @Override
    public BridgeInvocationSet emptySet() {
      return new BridgeInvocationSetImpl();
    }

    @Override
    public BridgeInvocationSet value() {
        return this;
    }

    @Override
    public List<BridgeInvocation> elements() {
        return Arrays.asList(toArray(new BridgeInvocation[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/invocation/impl/BridgeInvocationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.invocation.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.BridgeSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeSetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.BridgeInvocation;
import io.ciera.tool.sql.ooaofooa.invocation.BridgeInvocationSet;
import io.ciera.tool.sql.ooaofooa.value.V_PARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_PARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class BridgeInvocationSetImpl extends InstanceSet<BridgeInvocationSet,BridgeInvocation> implements BridgeInvocationSet {

    public BridgeInvocationSetImpl() {
    }

    public BridgeInvocationSetImpl(Comparator<? super BridgeInvocation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setBridgeNameColumn( int m_bridgeNameColumn ) throws XtumlException {
        for ( BridgeInvocation bridgeinvocation : this ) bridgeinvocation.setBridgeNameColumn( m_bridgeNameColumn );
    }
    @Override
    public void setExternalEntityKeyLettersLineNumber( int m_externalEntityKeyLettersLineNumber ) throws XtumlException {
        for ( BridgeInvocation bridgeinvocation : this ) bridgeinvocation.setExternalEntityKeyLettersLineNumber( m_externalEntityKeyLettersLineNumber );
    }
    @Override
    public void setBrg_ID( UniqueId ref_Brg_ID ) throws XtumlException {
        for ( BridgeInvocation bridgeinvocation : this ) bridgeinvocation.setBrg_ID( ref_Brg_ID );
    }
    @Override
    public void setBridgeNameLineNumber( int m_bridgeNameLineNumber ) throws XtumlException {
        for ( BridgeInvocation bridgeinvocation : this ) bridgeinvocation.setBridgeNameLineNumber( m_bridgeNameLineNumber );
    }
    @Override
    public void setExternalEntityKeyLettersColumn( int m_externalEntityKeyLettersColumn ) throws XtumlException {
        for ( BridgeInvocation bridgeinvocation : this ) bridgeinvocation.setExternalEntityKeyLettersColumn( m_externalEntityKeyLettersColumn );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( BridgeInvocation bridgeinvocation : this ) bridgeinvocation.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( BridgeInvocation bridgeinvocation : this ) act_smtset.add( bridgeinvocation.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public V_PARSet R628_takes_V_PAR() throws XtumlException {
        V_PARSet v_parset = new V_PARSetImpl();
        for ( BridgeInvocation bridgeinvocation : this ) v_parset.addAll( bridgeinvocation.R628_takes_V_PAR() );
        return v_parset;
    }
    @Override
    public BridgeSet R674_is_an_invocation_of_Bridge() throws XtumlException {
        BridgeSet bridgeset = new BridgeSetImpl();
        for ( BridgeInvocation bridgeinvocation : this ) bridgeset.add( bridgeinvocation.R674_is_an_invocation_of_Bridge() );
        return bridgeset;
    }


    @Override
    public BridgeInvocation nullElement() {
        return BridgeInvocationImpl.EMPTY_BRIDGEINVOCATION;
    }

    @Override
    public BridgeInvocationSet emptySet() {
      return new BridgeInvocationSetImpl();
    }

    @Override
    public BridgeInvocationSet emptySet(Comparator<? super BridgeInvocation> comp) {
      return new BridgeInvocationSetImpl(comp);
    }

    @Override
    public BridgeInvocationSet value() {
        return this;
    }

    @Override
    public List<BridgeInvocation> elements() {
        return Arrays.asList(toArray(new BridgeInvocation[0]));
    }

}
